require "hache"
require "sb/version"

class SB < String
  # Public: Append a string, making sure that it's escaped if it's not a "safe"
  # string (i.e. not an instance of SB).
  #
  # str - A String.
  #
  # Returns self.
  def <<(str)
    super(SB === str ? str : SB(Hache.h(str)))
  end

  # Public: Make sure converting this into a string doesn't mark it as unsafe.
  def to_s
    self
  end
end

# Public: Mark a string as safe by wrapping it in the SB class.
#
# Returns a SB instance.
def SB(str)
  SB.new(str)
end

# Monkeypatch String#dump so that Mote treats "regular" template text (i.e. not
# user provided interpolated content) as safe.
#
# FIXME: It'd be nice if Mote had some sort of hook method for this so that we
# didn't need to monkeypatch anything.
class String
  @@dump = instance_method(:dump)

  def dump
    "SB(#{@@dump.bind(self).call})"
  end
end
